@@ -28,11 +28,13 @@ public enum BooleanUserPreference {
     CHECK_UPDATES,
     CHECK_FOR_NEWS,
     PDF_COMPRESSION_ENABLED,
+    OVERWRITE_OUTPUT,
     PLAY_SOUNDS,
     DONATION_NOTIFICATION,
     PREMIUM_MODULES,
     HIGH_QUALITY_THUMB,
     SMART_OUTPUT,
     SAVE_WORKSPACE_ON_EXIT,
-    SAVE_PWD_IN_WORKSPACE;
+    SAVE_PWD_IN_WORKSPACE,
+    CLEAR_CONFIRMATION;
 }
