@@ -19,15 +19,16 @@
 package org.pdfsam.support;
 
 import static org.junit.Assert.assertEquals;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
-import javafx.beans.InvalidationListener;
-import javafx.beans.value.ChangeListener;
 
 import org.junit.Test;
 
+import javafx.beans.InvalidationListener;
+import javafx.beans.value.ChangeListener;
+
 /**
  * @author Andrea Vacondio
  *
