@@ -18,6 +18,7 @@
  */
 package org.pdfsam.ui.io;
 
+import java.io.File;
 import java.util.function.Consumer;
 
 import org.pdfsam.i18n.DefaultI18nContext;
@@ -26,7 +27,7 @@ import org.pdfsam.support.params.SingleOutputTaskParametersBuilder;
 import org.pdfsam.support.params.TaskParametersBuildStep;
 import org.pdfsam.ui.io.RememberingLatestFileChooserWrapper.OpenType;
 import org.pdfsam.ui.support.FXValidationSupport.ValidationState;
-import org.sejda.conversion.FileOutputAdapter;
+import org.sejda.model.output.FileTaskOutput;
 import org.sejda.model.parameter.base.SingleOutputTaskParameters;
 
 /**
@@ -47,7 +48,7 @@ public class BrowsablePdfOutputField extends BrowsableFileField implements
     public void apply(SingleOutputTaskParametersBuilder<?> builder, Consumer<String> onError) {
         getTextField().validate();
         if (getTextField().getValidationState() == ValidationState.VALID) {
-            builder.output(new FileOutputAdapter(getTextField().getText()).getFileOutput());
+            builder.output(new FileTaskOutput(new File(getTextField().getText())));
         } else {
             onError.accept(DefaultI18nContext.getInstance().i18n("The selected PDF file is invalid"));
         }
