@@ -18,11 +18,13 @@
  */
 package org.pdfsam.ui.module;
 
-import static org.sejda.eventstudio.StaticStudio.eventStudio;
+import static org.pdfsam.eventstudio.StaticStudio.eventStudio;
 
 import java.util.function.Consumer;
 
 import org.apache.commons.lang3.builder.Builder;
+import org.pdfsam.eventstudio.annotation.EventListener;
+import org.pdfsam.eventstudio.annotation.EventStation;
 import org.pdfsam.i18n.DefaultI18nContext;
 import org.pdfsam.module.Module;
 import org.pdfsam.module.TaskExecutionRequestEvent;
@@ -31,8 +33,6 @@ import org.pdfsam.ui.notification.NotificationType;
 import org.pdfsam.ui.support.Style;
 import org.pdfsam.ui.workspace.LoadWorkspaceEvent;
 import org.pdfsam.ui.workspace.SaveWorkspaceEvent;
-import org.sejda.eventstudio.annotation.EventListener;
-import org.sejda.eventstudio.annotation.EventStation;
 import org.sejda.model.parameter.base.AbstractParameters;
 
 import javafx.application.Platform;
@@ -83,6 +83,11 @@ public abstract class BaseTaskExecutionModule implements Module {
         Platform.runLater(() -> onLoadWorkspace(event.getData(id())));
     }
 
+    @EventListener
+    public void onRunButtonAccelerator(RunButtonTriggerRequest request) {
+        footer.runButton().fire();
+    }
+
     /**
      * @param onError
      *            function to be called in case of error while building the task parameters
