@@ -19,9 +19,11 @@
 package org.pdfsam.ui.selection.multiple;
 
 import java.io.File;
+import java.text.Collator;
 import java.util.Comparator;
 
 import org.pdfsam.i18n.DefaultI18nContext;
+import org.sejda.commons.util.NumericalSortFilenameComparator;
 
 import javafx.beans.property.ReadOnlyObjectWrapper;
 import javafx.beans.value.ObservableValue;
@@ -78,7 +80,7 @@ public enum FileColumn implements SelectionTableColumn<File> {
 
         @Override
         public Comparator<File> comparator() {
-            return new NumericalSortFilenameComparator().thenComparing(f -> f.getName().toLowerCase());
+            return new NumericalSortFilenameComparator(Comparator.comparing(File::getName, Collator.getInstance()));
         }
     }
 }
