@@ -23,14 +23,15 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
+import static org.pdfsam.eventstudio.StaticStudio.eventStudio;
 import static org.pdfsam.ui.selection.multiple.SelectionChangedEvent.select;
-import static org.sejda.eventstudio.StaticStudio.eventStudio;
 
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 import org.mockito.ArgumentCaptor;
 import org.pdfsam.NoHeadless;
+import org.pdfsam.eventstudio.Listener;
 import org.pdfsam.test.ClearEventStudioRule;
 import org.pdfsam.test.HitTestListener;
 import org.pdfsam.ui.commons.ClearModuleEvent;
@@ -40,7 +41,6 @@ import org.pdfsam.ui.selection.multiple.SelectionTableToolbar.MoveDownButton;
 import org.pdfsam.ui.selection.multiple.SelectionTableToolbar.MoveUpButton;
 import org.pdfsam.ui.selection.multiple.SelectionTableToolbar.RemoveButton;
 import org.pdfsam.ui.selection.multiple.move.MoveSelectedEvent;
-import org.sejda.eventstudio.Listener;
 import org.testfx.framework.junit.ApplicationTest;
 import org.testfx.util.WaitForAsyncUtils;
 
@@ -72,7 +72,7 @@ public class SelectionTableToolbarTest extends ApplicationTest {
     @Test
     public void clear() {
         HitTestListener<ClearModuleEvent> listener = new HitTestListener<>();
-        eventStudio().add(ClearModuleEvent.class, listener, MODULE);
+        eventStudio().add(ClearModuleEvent.class, listener);
         clickOn(b -> b instanceof ClearButton);
         assertTrue(listener.isHit());
     }
@@ -82,7 +82,7 @@ public class SelectionTableToolbarTest extends ApplicationTest {
     public void clearAllSettings() {
         Listener<ClearModuleEvent> listener = mock(Listener.class);
         ArgumentCaptor<ClearModuleEvent> captor = ArgumentCaptor.forClass(ClearModuleEvent.class);
-        eventStudio().add(ClearModuleEvent.class, listener, MODULE);
+        eventStudio().add(ClearModuleEvent.class, listener);
         SplitMenuButton btn = lookup("#clear-button").queryAs(SplitMenuButton.class);
         for (Node child : btn.getChildrenUnmodifiable()) {
             if (child.getStyleClass().contains("arrow-button")) {
