@@ -19,7 +19,7 @@
 package org.pdfsam.ui.banner;
 
 import static org.pdfsam.ui.commons.SetActiveModuleRequest.activeteModule;
-import static org.sejda.eventstudio.StaticStudio.eventStudio;
+import static org.pdfsam.eventstudio.StaticStudio.eventStudio;
 
 import java.util.HashMap;
 import java.util.List;
