@@ -18,12 +18,12 @@
  */
 package org.pdfsam.ui.dashboard.preference;
 
-import static org.sejda.eventstudio.StaticStudio.eventStudio;
+import static org.pdfsam.eventstudio.StaticStudio.eventStudio;
 
 import org.pdfsam.i18n.DefaultI18nContext;
+import org.pdfsam.injector.Prototype;
 import org.pdfsam.module.ClearUsageRequestEvent;
 import org.pdfsam.ui.support.Style;
-import org.sejda.injector.Prototype;
 
 import javafx.scene.control.Button;
 
