@@ -20,8 +20,8 @@ package org.pdfsam.ui.dialog;
 
 import org.pdfsam.ui.support.Style;
 
-import de.jensd.fx.glyphs.GlyphsDude;
 import de.jensd.fx.glyphs.materialdesignicons.MaterialDesignIcon;
+import de.jensd.fx.glyphs.materialdesignicons.utils.MaterialDesignIconFactory;
 import javafx.scene.control.Label;
 import javafx.scene.layout.HBox;
 import javafx.scene.layout.VBox;
@@ -43,7 +43,7 @@ class ConfirmationDialogContent extends HBox {
         messageContent.getStyleClass().add("-pdfsam-dialog-message");
         VBox messages = new VBox(messageTitle, messageContent);
         messages.getStyleClass().add("-pdfsam-dialog-messages");
-        getChildren().addAll(GlyphsDude.createIcon(icon, "42.0"), messages);
+        getChildren().addAll(MaterialDesignIconFactory.get().createIcon(icon, "42.0"), messages);
         getStyleClass().addAll("-pdfsam-dialog-content");
     }
 
