@@ -18,8 +18,6 @@
  */
 package org.pdfsam.module;
 
-import java.util.List;
-
 import org.pdfsam.injector.Components;
 import org.pdfsam.injector.Provides;
 
@@ -30,7 +28,7 @@ import org.pdfsam.injector.Provides;
 @Components({ ClearUsageController.class })
 public class ModuleServiceConfig {
     @Provides
-    UsageService usageService(List<Module> modules, PreferencesUsageDataStore dataStore) {
-        return new StatefulPreferencesUsageService(modules, dataStore);
+    UsageService usageService(PreferencesUsageDataStore dataStore) {
+        return new StatefulPreferencesUsageService(dataStore);
     }
 }
