@@ -18,12 +18,7 @@
  */
 package org.pdfsam.module;
 
-import static java.util.stream.Collectors.toList;
-
-import java.util.List;
-import java.util.Map;
 import java.util.prefs.Preferences;
-import java.util.stream.Collectors;
 
 import javax.inject.Inject;
 
@@ -35,12 +30,10 @@ import javax.inject.Inject;
  */
 class StatefulPreferencesUsageService implements UsageService {
 
-    private PreferencesUsageDataStore dataStore;
-    private Map<String, Module> modulesMap;
+    private final PreferencesUsageDataStore dataStore;
 
     @Inject
-    StatefulPreferencesUsageService(List<Module> modules, PreferencesUsageDataStore dataStore) {
-        this.modulesMap = modules.stream().collect(Collectors.toMap(Module::id, m -> m));
+    StatefulPreferencesUsageService(PreferencesUsageDataStore dataStore) {
         this.dataStore = dataStore;
     }
 
@@ -49,20 +42,6 @@ class StatefulPreferencesUsageService implements UsageService {
         dataStore.incrementUsageFor(moduleId);
     }
 
-    @Override
-    public List<Module> getMostUsed() {
-        List<ModuleUsage> used = dataStore.getUsages();
-        used.sort((a, b) -> Long.compare(b.getTotalUsed(), a.getTotalUsed()));
-        return used.stream().map(u -> modulesMap.get(u.getModuleId())).filter(m -> m != null).collect(toList());
-    }
-
-    @Override
-    public List<Module> getMostRecentlyUsed() {
-        List<ModuleUsage> used = dataStore.getUsages();
-        used.sort((a, b) -> Long.compare(b.getLastSeen(), a.getLastSeen()));
-        return used.stream().map(u -> modulesMap.get(u.getModuleId())).filter(m -> m != null).collect(toList());
-    }
-
     @Override
     public void clear() {
         dataStore.clear();
