@@ -18,8 +18,6 @@
  */
 package org.pdfsam.module;
 
-import java.util.List;
-
 /**
  * Service providing modules usage related functionalities
  * 
@@ -35,16 +33,6 @@ public interface UsageService {
      */
     void incrementUsageFor(String moduleId);
 
-    /**
-     * @return a sorted list with the most used modules
-     */
-    List<Module> getMostUsed();
-
-    /**
-     * @return a sorted list with the most recently modules
-     */
-    List<Module> getMostRecentlyUsed();
-
     /**
      * Clear usage statistics
      */
