@@ -18,7 +18,7 @@
  */
 package org.pdfsam.ui;
 
-import static org.pdfsam.support.RequireUtils.requireNotNull;
+import static org.sejda.commons.util.RequireUtils.requireNotNullArg;
 
 import java.io.File;
 import java.io.FileInputStream;
@@ -30,6 +30,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.fasterxml.jackson.jr.ob.JSON;
+import com.fasterxml.jackson.jr.ob.JSON.Feature;
 
 /**
  * Implementation of the workspace service where data is stored and loaded in json format
@@ -39,14 +40,15 @@ import com.fasterxml.jackson.jr.ob.JSON;
  */
 class JsonWorkspaceService implements WorkspaceService {
     private static final Logger LOG = LoggerFactory.getLogger(JsonWorkspaceService.class);
+    private JSON jackson = new JSON().without(Feature.USE_FIELDS).with(JSON.Feature.PRETTY_PRINT_OUTPUT)
+            .without(JSON.Feature.WRITE_NULL_PROPERTIES);
 
     @Override
     public void saveWorkspace(Map<String, Map<String, String>> data, File destination) {
-        requireNotNull(destination, "Destination file cannot be null");
+        requireNotNullArg(destination, "Destination file cannot be null");
         LOG.debug(DefaultI18nContext.getInstance().i18n("Saving workspace data to {0}", destination.getAbsolutePath()));
         try {
-            JSON.std.with(JSON.Feature.PRETTY_PRINT_OUTPUT).without(JSON.Feature.WRITE_NULL_PROPERTIES)
-                    .write(data, destination);
+            jackson.write(data, destination);
             LOG.info(DefaultI18nContext.getInstance().i18n("Workspace saved"));
         } catch (Exception e) {
             // make it unchecked
@@ -57,10 +59,10 @@ class JsonWorkspaceService implements WorkspaceService {
     @Override
     @SuppressWarnings("unchecked")
     public Map<String, Map<String, String>> loadWorkspace(File workspace) {
-        requireNotNull(workspace, "Workspace file cannot be null");
+        requireNotNullArg(workspace, "Workspace file cannot be null");
         Map<String, Map<String, String>> data = Collections.emptyMap();
         try (FileInputStream stream = new FileInputStream(workspace)) {
-            data = (Map) JSON.std.mapFrom(stream);
+            data = (Map) jackson.mapFrom(stream);
         } catch (Exception e) {
             // make it unchecked
             throw new RuntimeException(e);
