@@ -31,6 +31,9 @@ import javax.inject.Named;
 import org.apache.commons.lang3.builder.Builder;
 import org.pdfsam.context.UserContext;
 import org.pdfsam.i18n.DefaultI18nContext;
+import org.pdfsam.injector.Auto;
+import org.pdfsam.injector.Components;
+import org.pdfsam.injector.Provides;
 import org.pdfsam.module.ModuleCategory;
 import org.pdfsam.module.ModuleDescriptor;
 import org.pdfsam.module.ModuleInputOutputType;
@@ -46,11 +49,8 @@ import org.pdfsam.ui.module.RunButton;
 import org.pdfsam.ui.prefix.PrefixPane;
 import org.pdfsam.ui.selection.single.TaskParametersBuilderSingleSelectionPane;
 import org.pdfsam.ui.support.Views;
-import org.sejda.eventstudio.annotation.EventListener;
-import org.sejda.eventstudio.annotation.EventStation;
-import org.sejda.injector.Auto;
-import org.sejda.injector.Components;
-import org.sejda.injector.Provides;
+import org.pdfsam.eventstudio.annotation.EventListener;
+import org.pdfsam.eventstudio.annotation.EventStation;
 import org.sejda.model.parameter.AbstractSplitByPageParameters;
 import org.sejda.model.prefix.Prefix;
 
@@ -75,7 +75,7 @@ public class SplitModule extends BaseTaskExecutionModule {
     private BrowsableOutputDirectoryField destinationDirectoryField;
     private PdfDestinationPane destinationPane;
     private SplitOptionsPane splitOptions = new SplitOptionsPane();
-    private PrefixPane prefix = new PrefixPane();
+    private PrefixPane prefix;
     private ModuleDescriptor descriptor = builder().category(ModuleCategory.SPLIT)
             .inputTypes(ModuleInputOutputType.SINGLE_PDF).name(DefaultI18nContext.getInstance().i18n("Split"))
             .description(DefaultI18nContext.getInstance().i18n("Split a PDF document at the given page numbers."))
@@ -83,7 +83,8 @@ public class SplitModule extends BaseTaskExecutionModule {
 
     @Inject
     public SplitModule(@Named(MODULE_ID + "field") BrowsableOutputDirectoryField destinationDirectoryField,
-            @Named(MODULE_ID + "pane") PdfDestinationPane destinationPane, @Named(MODULE_ID + "footer") Footer footer) {
+            @Named(MODULE_ID + "pane") PdfDestinationPane destinationPane, @Named(MODULE_ID + "footer") Footer footer,
+            @Named(MODULE_ID + "prefix") PrefixPane prefix) {
         super(footer);
         this.destinationDirectoryField = destinationDirectoryField;
         this.destinationPane = destinationPane;
@@ -91,6 +92,7 @@ public class SplitModule extends BaseTaskExecutionModule {
         this.selectionPane.setPromptText(
                 DefaultI18nContext.getInstance().i18n("Select or drag and drop the PDF you want to split"));
         this.selectionPane.addOnLoaded(d -> splitOptions.setMaxPages(d.pages().getValue()));
+        this.prefix = prefix;
         initModuleSettingsPanel(settingPanel());
     }
 
@@ -195,5 +197,11 @@ public class SplitModule extends BaseTaskExecutionModule {
         public OpenButton openButton() {
             return new OpenButton(MODULE_ID, ModuleInputOutputType.MULTIPLE_PDF);
         }
+
+        @Provides
+        @Named(MODULE_ID + "prefix")
+        public PrefixPane prefixPane(UserContext userContext) {
+            return new PrefixPane(MODULE_ID, userContext);
+        }
     }
 }
